@@ -449,6 +449,30 @@ sar_bool sar_lookPathPos_c(sarNode_p currNode, const char * checkStr, long start
 	    		}
 	    	}
 
+	    	if (plusNode->alphaNumNode != (sarNode_p)NULL) {
+	    		if (! isALNUM(checkChar)) {
+	        		sarNode_p nextPlusNode = plusNode->alphaNumNode;
+	        		sar_bool plusNodesMatched = sar_matchPlusNode_c(nextPlusNode, checkStr, startPos, currPos, len, SAR_ALPHA_NUM, negative);
+	        		matched = matched || plusNodesMatched;
+	    		}
+	    	}
+
+	    	if (plusNode->alphaNode != (sarNode_p)NULL) {
+	    		if (! isALPHA(checkChar)) {
+	        		sarNode_p nextPlusNode = plusNode->alphaNode;
+	        		sar_bool plusNodesMatched = sar_matchPlusNode_c(nextPlusNode, checkStr, startPos, currPos, len, SAR_ALPHA, negative);
+	        		matched = matched || plusNodesMatched;
+	    		}
+	    	}
+
+	    	if (plusNode->spaceNode != (sarNode_p)NULL) {
+	    		if (! isSPACE(checkChar)) {
+	        		sarNode_p nextPlusNode = plusNode->spaceNode;
+	        		sar_bool plusNodesMatched = sar_matchPlusNode_c(nextPlusNode, checkStr, startPos, currPos, len, SAR_SPACE, negative);
+	        		matched = matched || plusNodesMatched;
+	    		}
+	    	}
+
     	}
     	else {
     		int existListPlusNodePos = sar_searchChar_c(plusNode->sarPathChars, plusNode->charNumber, checkChar);
@@ -608,4 +632,3 @@ void sar_lookPathFromPos_c(sarNode_p rootNode, long pos, const char * checkStr,
 
 
 
-
